hasGnuMake: Check if GNU Make is available via the 'make' command

View source: R/hasGnuMake.R

hasGnuMakeR Documentation

Check if GNU Make is available via the 'make' command

Description

Function checks if GNU Make is installed and available in the system PATH via the 'make' command. It also verifies that the version of GNU Make is at least the minimum required version needed by the package, which is currently set to 3.82.

Usage

hasGnuMake()

Value

Logical value indicating if GNU Make is available

Author(s)

Michal Burda

Examples

if (hasGnuMake()) {
  message("GNU Make is available")
}

rmake documentation built on Sept. 25, 2026, 5:06 p.m.