sanitizePath: Sanitize a file path for the current operating system

View source: R/sanitizePath.R

sanitizePathR Documentation

Sanitize a file path for the current operating system

Description

This function replaces forward slashes with backslashes on Windows systems, and leaves the path unchanged on Unix-like systems.

Usage

sanitizePath(path)

Arguments

path

A character string representing the file path to be sanitized.

Value

A sanitized file path suitable for the current operating system.

Author(s)

Michal Burda


rmake documentation built on Sept. 25, 2026, 5:06 p.m.