| hasGnuMake | R Documentation |
Function checks if GNU Make is installed and available in the system PATH via the 'make' command. It also verifies that the version of GNU Make is at least the minimum required version needed by the package, which is currently set to 3.82.
hasGnuMake()
Logical value indicating if GNU Make is available
Michal Burda
if (hasGnuMake()) {
message("GNU Make is available")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.