Learn R Programming

rmake (version 1.2.3)

hasGnuMake: Check if GNU Make is available via the 'make' command

Description

Function checks if GNU Make is installed and available in the system PATH via the 'make' command. It also verifies that the version of GNU Make is at least the minimum required version needed by the package, which is currently set to 3.82.

Usage

hasGnuMake()

Arguments

Value

Logical value indicating if GNU Make is available

Author

Michal Burda

Examples

Run this code
if (hasGnuMake()) {
  message("GNU Make is available")
}

Run the code above in your browser using DataLab